@@ -22,10 +22,6 @@
 #include <QMessageBox>
 #include <phonon/AudioOutput>
 
-#ifdef Q_WS_HILDON // Qt 4.5-4.6 compatibility
-#define Q_WS_MAEMO_5
-#endif // Q_WS_HILDON
-
 #ifdef Q_WS_MAEMO_5
 #include <QtDBus/QDBusMessage>
 #include <QtDBus/QDBusConnection>
